---
name: 🚀 Feature request
about: Suggest an idea for this project.
labels: [feature, triage]
title: ''
assignees: ''
---

<!-- ⚠️ If you do not respect this template, your issue will be closed -->
<!-- ⚠️ Make sure to browse the opened and closed issues to confirm this idea does not exist. -->

### What is the expected behavior?
<!-- Please, provide a clear and concise description of the expected behavior for this feature. -->
